@@ -3,7 +3,7 @@
 ##                                                                          ##
 ##          MATLAB Independent, Small & Safe, High Integrity Tools          ##
 ##                                                                          ##
-##              Copyright (C) 2020-2021, Florian Schanda                    ##
+##              Copyright (C) 2020-2022, Florian Schanda                    ##
 ##              Copyright (C) 2020, Veoneer System Software GmbH            ##
 ##                                                                          ##
 ##  This file is part of MISS_HIT.                                          ##
@@ -320,7 +320,10 @@ def check_metric(mh, cfg, loc, metric, metrics, justifications):
             else:
                 mh.metric_issue(loc,
                                 "exceeded %s: measured %u > limit %u" %
-                                (metric, measure, limit))
+                                (config.METRICS[metric].longname.lower(),
+                                 measure,
+                                 limit),
+                                metric)
 
 
 def get_justifications(mh, n_root):
@@ -964,10 +967,11 @@ class MH_Metric(command_line.MISS_HIT_Back_End):
 
         # Create lexer
 
-        lexer = MATLAB_Lexer(wp.mh, wp.get_content(),
-                             wp.filename, wp.blockname)
-        if wp.cfg.octave:
-            lexer.set_octave_mode()
+        lexer = MATLAB_Lexer(wp.cfg.language,
+                             wp.mh,
+                             wp.get_content(),
+                             wp.filename,
+                             wp.blockname)
         if not wp.cfg.pragmas:
             lexer.process_pragmas = False
 
